Learn R Programming

ConsensusClustering (version 1.5.0)

consensus_matrix_multiview: Calculate consensus matrix for multi-data consensus clustering

Description

Calculate consensus matrix for multi-data consensus clustering

Usage

consensus_matrix_multiview(
  X,
  max.cluster = 5,
  sample.set = NA,
  clustering.method = "hclust",
  adj.conv = TRUE,
  verbos = TRUE
)

Value

description list of consensus matrices for each k

Arguments

X

list of adjacency matrices for different cohorts (or views).

max.cluster

maximum number of clusters

sample.set

vector of samples the clustering is being applied on. sample.set can be names or indices. if sample.set is NA, it considers that all the datasets have the same samples with the same order.

clustering.method

base clustering method: c("hclust", "spectral", "pam")

adj.conv

binary value to apply soft threshold (default=TRUE)

verbos

binary value for verbosity (default=TRUE)

Details

performs multi-data consensus clustering and obtain consensus matrix Monti et al. (2003) consensus clustering algorithm

Examples

Run this code
data = multiview_clusters (n = c(40,40,40), hidden.dim = 2, observed.dim = c(2,2,2),
sd.max = .1, sd.noise = 0, hidden.r.range = c(.5,1))
X_observation = data[["observation"]]
Adj = list()
for (i in 1:length(X_observation))
  Adj[[i]] = adj_mat(X_observation[[i]], method = "euclidian")
CM = consensus_matrix_multiview(Adj, max.cluster = 4, verbos = FALSE)

Run the code above in your browser using DataLab