Learn R Programming

ConsensusClustering (version 1.5.0)

multiview_pam_gen: Multiview PAM (K-medoids) generation

Description

Multiview PAM (K-medoids) generation

Usage

multiview_pam_gen(
  X,
  rep = 10,
  range.k = c(2, 5),
  is.distance = FALSE,
  method = "random",
  sample.set = NA
)

Value

matrix of clusterings Nsample x (Nrepeat x Nviews)

Arguments

X

List of input data matrices of Sample x feature or distance matrices. The length of X is equal to Nviews

rep

number of repeats

range.k

vector of minimum and maximum values for k c(min, max)

is.distance

binary balue indicating if the input X is distance

method

method for the choice of k at each repeat c("random", "silhouette")

sample.set

vector of samples the clustering is being applied on. can be names or indices. if sample.set is NA, it considers all the datasets have the same samples with the same order

Details

At each repeat, k is selected randomly or based on the best silhouette width from a discrete uniform distribution between range.k[1] and range.k[2]. Then PAM clustering is applied and result is returned.

Examples

Run this code
data = multiview_clusters (n = c(40,40,40), hidden.dim = 2, observed.dim = c(2,2,2),
sd.max = .1, sd.noise = 0, hidden.r.range = c(.5,1))
X_observation = data[["observation"]]
Clusters = multiview_pam_gen(X_observation)

Run the code above in your browser using DataLab